.. include:: ../../README.rst

.. toctree::
   :caption: General
   :maxdepth: 1
   :hidden:

   about
   installation
   release_notes
   citing
   references

.. toctree::
   :caption: Docs
   :maxdepth: 1
   :hidden:

   api
   cli

.. toctree::
   :caption: Tutorial
   :maxdepth: 1
   :hidden:

   caller
   example
